# -*- coding: utf-8 -*-
from plone.uuid.interfaces import IUUID
from zope.publisher.browser import BrowserView

import sys


if sys.version_info >= (3,):
    text_type = str
else:
    text_type = unicode


class UUIDView(BrowserView):
    """A simple browser view that renders the UUID of its context
    """

    def __call__(self):
        return text_type(IUUID(self.context, u""))



# -*- coding: utf-8 -*-
from plone.uuid.interfaces import IUUIDGenerator
from zope.deprecation import deprecate
from zope.interface import implementer

import uuid


@implementer(IUUIDGenerator)
class UUID4Generator(object):
    """Default UUID implementation.

    Uses uuid.uuid4()
    """

    def __call__(self):
        return uuid.uuid4().hex


@deprecate(
    'UUID1Generator was renamed to UUID4Generator, as we use uuid4 instead of '
    'uuid1. Please use UUID4Generator instead.'
)
class UUID1Generator(UUID4Generator):
    """BBB. Remove with next major version.
    """



# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup


version = '1.0.6'

long_description = (
    open('README.rst').read() + '\n' +
    open('CHANGES.rst').read() + '\n'
)

setup(
    name='plone.uuid',
    version=version,
    description="UUIDs for content items",
    long_description=long_description,
    # Get more strings from
    # https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Plone",
        "Framework :: Plone :: 4.3",
        "Framework :: Plone :: 5.0",
        "Framework :: Plone :: 5.1",
        "Framework :: Plone :: 5.2",
        "Framework :: Plone :: Core",
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    keywords='plone uuid',
    author='Martin Aspeli',
    author_email='optilude@gmail.com',
    url='https://github.com/plone/plone.uuid',
    license='BSD',
    packages=find_packages(),
    namespace_packages=['plone'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'Acquisition',
        'setuptools',
        'zope.component',
        'zope.browserpage',
        'zope.interface',
        'zope.lifecycleevent',
        'zope.publisher',
    ],
    extras_require={
        'test': [
            'zope.configuration',
            'zope.event',
        ]
    },
    entry_points="""
    """,
)
